@@ -37,7 +37,7 @@ able to narrow down the possibilities.
 
 """
 
-import tempfile, errno, signal, cPickle, C, pickle
+import tempfile, errno, signal, cPickle, C
 from static import *
 
 
@@ -598,7 +598,7 @@ class Resume:
 		fp = checkpoint_rp.open("rb")
 		data = fp.read()
 		fp.close()
-		return pickle.loads(data)
+		return cPickle.loads(data)
 
 	def ResumeCheck(cls):
 		"""Return relevant ResumeSessionInfo if there's one we should resume
